@@ -27,7 +27,7 @@
       -- The following columns have been identified as added/updated
       {% for c in cols %}
           -- {{ c }}
-          ALTER TABLE IF EXITS {{ '"{{ target.DB }}"."{{ target.SCH }}"' }}.{{ ddl.OBJ_NAME }} 
+          ALTER TABLE IF EXISTS {{ '"{{ target.DB }}"."{{ target.SCH }}"' }}.{{ ddl.OBJ_NAME }} 
            add column {{ c.OBJ_NAME }} {{ c.DATA_TYPE }} {% if c.COLUMN_DEFAULT is defined %}  DEFAULT {{ c.COLUMN_DEFAULT }} {% endif %}
           ;
       {% endfor %}
